@@ -1,10 +1,10 @@
 //! # Properties of number types
-use num::Zero;
+use relp_num::NonZero;
 
 use crate::data::linear_algebra::traits::Element;
 
 pub trait Rhs =
-    Zero +
+    NonZero +
     Eq +
     Element +
 ;
