@@ -2,5 +2,3 @@
 //!
 //! Solving network problems as linear programs.
 pub mod representation;
-pub mod shortest_path;
-pub mod max_flow;
